@@ -1,4 +1,4 @@
-from django.contrib.auth.models import User
+from django.contrib.auth import get_user_model
 from django.core.management.base import NoArgsCommand
 
 from delicious_cake.models import ApiKey
@@ -11,7 +11,7 @@ class Command(NoArgsCommand):
         """Goes through all users and adds API keys for any that don't have one."""
         self.verbosity = int(options.get('verbosity', 1))
 
-        for user in User.objects.all().iterator():
+        for user in get_user_model().objects.all().iterator():
             try:
                 api_key = ApiKey.objects.get(user=user)
 
